# PyBbox2

![Bbox](http://www.bbox-actus.com/img/upload/bbox-sensation-adsl-modem.jpg)

This is a API wrapper for the french Bouygues router Bbox.

This aims to provide both a thin wrapper (but still handling authentication), AND
a full callable API.
